
create table Site(
	SiteID nvarchar(255) primary key,
	SiteAddress nvarchar(255) NotEmpty,
	SiteUnitNumber nvarchar(255),
	SiteCity nvarchar(255) NotEmpty,
	SiteState nvarchar(255) NotEmpty,
	SiteZipCode nvarchar(255) NotEmpty,
	ServiceAccountID nvarchar(255),
	ServiceAccountName nvarchar(255),
	NAICSCode nvarchar(255),
	ResidentialFlag bit NotEmpty);

create table Contact(
	ContactID nvarchar(255) primary key,
	ContactType nvarchar(255) NotEmpty,
	ContactName nvarchar(255) NotEmpty,
	ContactPhoneNumber numeric NotEmpty,
	ContactPhoneExtension numeric,
	ContactPhoneType nvarchar(255),
	ContactPhoneNumberAlt numeric,
	ContactPhoneExtensionAlt numeric,
	ContactPhoneTypeAlt nvarchar(255),
	ContactEmail nvarchar(255));

create table ProgramCost(
	PrgID nvarchar(255) CedarsValueList PrgID NotEmpty,
	PrgYear nvarchar(4) NotEmpty,
	ClaimYearQuarter CedarsYearQuarter NotEmpty,
	AdminCostsOverheadAndGA numeric NotEmpty,
	AdminCostsOther numeric NotEmpty,
	MarketingOutreach numeric NotEmpty,
	DirectImplementationActivity numeric NotEmpty,
	DirectImplementationInstallation numeric NotEmpty,
	DirectImplementationHardwareAndMaterials numeric NotEmpty,
	DirectImplementationRebateAndInspection numeric NotEmpty,
	EMV numeric NotEmpty,
	IncentRebatesUserInputIncentive numeric NotEmpty,
	CostsRecoveredFromOtherSources numeric NotEmpty,
	OnBillFinancing numeric NotEmpty,
	PA nvarchar(255) CedarsValueList PA NotEmpty,
	primary key (PrgID, PrgYear));

create table Claim(
	ClaimID nvarchar(255) primary key,
	SiteID nvarchar(255) references Site,
	PrgID nvarchar(255) CedarsValueList PrgID NotEmpty,
	ImplementationPA nvarchar(255) CedarsValueList PA,
	ImplementationID nvarchar(255),
	CostQualifier nvarchar(255) CedarsValueList CostQualifier,
	BldgType nvarchar(255) NotEmpty CedarsValueList BldgType,
	BldgLoc nvarchar(255) CedarsValueList BldgLoc NotEmpty,
	BldgVint nvarchar(255) CedarsValueList BldgVint NotEmpty,
	BldgHVAC nvarchar(255) CedarsValueList BldgHVAC NotEmpty,
	NormUnit nvarchar(255) CedarsValueList NormUnit NotEmpty,
	Sector nvarchar(255) NotEmpty CedarsValueList Sector,
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	DeliveryType nvarchar(20) CedarsValueList DeliveryType,
	PrgElement nvarchar(255),
	ProjectID nvarchar(255),
	ProjectDescription nvarchar(500),
	NAICSBldgType nvarchar(255),
	E3TargetSector nvarchar(255),
	E3MeaElecEndUseShape nvarchar(255),
	E3GasSector nvarchar(255) CedarsValueList E3GasSector,
	E3GasSavProfile nvarchar(255) CedarsValueList E3GasSavProfile,
	E3ClimateZone nvarchar(255) CedarsValueList E3ClimateZone NotEmpty,
	NumUnits numeric NotEmpty,
	InstalledNumUnits numeric,
	InstalledNormUnit nvarchar(255) CedarsValueList NormUnit,
	NTGRkW numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRkWh numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRTherm numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRCost numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTG_ID nvarchar(50) CedarsValueList NTG,
	TotalFirstYearGrosskW numeric NotEmpty,
	TotalFirstYearGrosskWh numeric NotEmpty,
	TotalFirstYearGrossTherm numeric NotEmpty,
	TotalFirstYearNetkW numeric NotEmpty,
	TotalFirstYearNetkWh numeric NotEmpty,
	TotalFirstYearNetTherm numeric NotEmpty,
	TotalLifecycleGrosskW numeric NotEmpty,
	TotalLifecycleGrosskWh numeric NotEmpty,
	TotalLifecycleGrossTherm numeric NotEmpty,
	TotalLifecycleNetkW numeric NotEmpty,
	TotalLifecycleNetkWh numeric NotEmpty,
	TotalLifecycleNetTherm numeric NotEmpty,
	TotalGrossMeasureCost numeric NotEmpty,
	TotalGrossIncentive numeric NotEmpty,
	UnitEndUserRebate numeric,
	UnitIncentiveToOthers numeric,
	UnitDirectInstallLab numeric,
	UnitDirectInstallMat numeric,
	UnitMeaCost1stBaseline numeric WarningCedarsNumRange [0, ) NotEmpty,
	UnitMeaCost2ndBaseline numeric CedarsNumRange [0, ) NotEmpty,
	WhySavingsZeroed nvarchar(255),
	WhyCostsZeroed nvarchar(255),
	PartialPaymentPercent numeric CedarsNumRange [0, 1],
	PartialPaymentFinalFlag bit NotEmpty,
	UpstreamFlag bit NotEmpty,
	ResidentialFlag bit NotEmpty,
	EUC_Flag bit NotEmpty,
	LGP_Flag bit NotEmpty,
	REN_Flag bit NotEmpty,
	OBF_Flag bit NotEmpty,
	Prop39_Flag bit NotEmpty,
	PublicK_12Flag bit NotEmpty,
	SchoolIdentifier nvarchar(255),
	FundingCycle CedarsFundingCycle NotEmpty,
	ClaimYearQuarter CedarsYearQuarter NotEmpty,
	ApplicationCode nvarchar(255),
	ApplicationDate WarningCedarsDate NotEmpty,
	InstallationDate CedarsDate NotEmpty,
	PaidDate CedarsDate,
	CustomerAgreementDate CedarsDate,
	ProjectCompletionDate CedarsDate NotEmpty,
	AuthorizedSignatureDate WarningCedarsDate,
	ClaimDate CedarsDate,

create table dbo.CustomMeasure(
	ClaimID nvarchar(255) primary key references Claim,
	MeasCode nvarchar(255),
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	MeasDescription nvarchar(255) NotEmpty,
	UseSubCategory nvarchar(255) CedarsValueList UseSubCategory NotEmpty,
	TechType nvarchar(255) CedarsValueList TechType NotEmpty,
	UnitkW1stBaseline numeric NotEmpty,
	UnitkWh1stBaseline numeric NotEmpty,
	UnitTherm1stBaseline numeric NotEmpty,
	UnitkW2ndBaseline numeric NotEmpty,
	UnitkWh2ndBaseline numeric NotEmpty,
	UnitTherm2ndBaseline numeric NotEmpty,
	EUL numeric CedarsNumRange [0, 30] NotEmpty,
	RUL numeric CedarsNumRange [0, ) NotEmpty,
	RealizationRatekW numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRatekWh numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateTherm numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateCost numeric CedarsNumRange (0, 2] NotEmpty,
	InstallationRatekW numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRatekWh numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateTherm numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateCost numeric CedarsNumRange (0, 1] NotEmpty,
	RevisedFlag bit NotEmpty,
	Comments nvarchar(255));

create table dbo.DeemedMeasure(
	ClaimID nvarchar(255) primary key references Claim,
	MeasCode nvarchar(255) NotEmpty,
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	MeasDescription nvarchar(255) NotEmpty,
	UnitkW1stBaseline numeric NotEmpty,
	UnitkWh1stBaseline numeric NotEmpty,
	UnitTherm1stBaseline numeric NotEmpty,
	UnitkW2ndBaseline numeric NotEmpty,
	UnitkWh2ndBaseline numeric NotEmpty,
	UnitTherm2ndBaseline numeric NotEmpty,
	EUL numeric CedarsNumRange (0, 30] NotEmpty,
	RUL numeric CedarsNumRange [0, 20.4) NotEmpty,
	RealizationRatekW numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRatekWh numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateTherm numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateCost numeric CedarsNumRange (0, 2] NotEmpty,
	InstallationRatekW numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRatekWh numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateTherm numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateCost numeric CedarsNumRange (0, 1] NotEmpty,
	RevisedFlag bit NotEmpty,
	Comments nvarchar(255),
	SourceDesc nvarchar(100) NotEmpty,
	Version nvarchar(50) CedarsValueList Version NotEmpty,
	VersionSource nvarchar(50) CedarsValueList VersionSource NotEmpty,
	DeliveryType nvarchar(20) CedarsValueList DeliveryType NotEmpty,
	StartDate CedarsDate NotEmpty,
	MeasQualifier nvarchar(50),
	MeasureID nvarchar(100) NotEmpty,
	EnergyImpactID nvarchar(100) NotEmpty,
	GSIA_ID nvarchar(50) CedarsValueList GSIA NotEmpty,
	NTG_ID nvarchar(50) CedarsValueList NTG NotEmpty,
	EUL_ID nvarchar(100) CedarsValueList EUL NotEmpty,
	RUL_ID nvarchar(100) CedarsValueList EUL,
	MeasCostID nvarchar(50) NotEmpty,
	StdCostID nvarchar(50),
	MeasImpactType nvarchar(50) CedarsValueList MeasImpactType NotEmpty,
	UseCategory nvarchar(50) CedarsValueList UseCategory NotEmpty,
	UseSubCategory nvarchar(50) CedarsValueList UseSubCategory NotEmpty,
	TechGroup nvarchar(50) CedarsValueList TechGroup NotEmpty,
	TechType nvarchar(50) CedarsValueList TechType NotEmpty,
	IETableName nvarchar(255),
	MeasTechID nvarchar(255),
	LaborRate nvarchar(255) CedarsValueList LaborRate,
	LocCostAdj nvarchar(255) CedarsValueList LocCostAdj NotEmpty,
	PreDesc nvarchar(255),
	StdDesc nvarchar(255),
	PreTechGroup nvarchar(50) CedarsValueList TechGroup NotEmpty,
	PreTechType nvarchar(50) CedarsValueList TechType NotEmpty,
	StdTechGroup nvarchar(50) CedarsValueList TechGroup NotEmpty,
	StdTechType nvarchar(50) CedarsValueList TechType NotEmpty,
	MeasImpactCalcType nvarchar(50) CedarsValueList MeasImpactCalcType NotEmpty);

create table ContactClaim(
	ClaimID nvarchar(255) references Claim NotEmpty,
	ContactID nvarchar(255) references Contact NotEmpty,
	primary key (ContactID, ClaimID));

